@@ -303,27 +303,27 @@ create_main_window (void)
                 "</ui>";
 
         static GtkActionEntry entries [] = {
-                { "game-menu", NULL, "_Game" },
-                { "new-game", GTK_STOCK_NEW, "_New game", "<Control>N", "Start a new game", G_CALLBACK (on_game_new_activate) },
-                { "restart-game", GTK_STOCK_REFRESH, "_Restart game", "<Control>R", "Restart the current game", G_CALLBACK (on_game_restart_activate) },
-                { "show-hint", GTK_STOCK_HELP, "_Hint", NULL, "Get a hint for the next action", G_CALLBACK (on_game_hint_activate) },
-                { "quit-game", GTK_STOCK_QUIT, "_Quit", "<Control>Q", "Quit application", G_CALLBACK (on_game_quit_activate) },
-                { "settings-menu", NULL, "_Settings" },
-                { "show-preferences", GTK_STOCK_PREFERENCES, "_Preferences", NULL, "Show game preferences", G_CALLBACK (on_preferences_activate) },
-                { "control-menu", NULL, "_Control" },
-                { "hand-deal", NULL, "Deal", NULL, "Deal a new hand", G_CALLBACK (on_control_deal_activate) },
-                { "hand-hit", NULL, "_Hit", "H", "Add a card to the hand", G_CALLBACK (on_control_hit_activate) },
-                { "hand-stand", NULL, "_Stand", "S", "Stop adding cards to the hand", G_CALLBACK (on_control_stand_activate) },
-                { "hand-surrender", NULL, "Surrender", "R", "Surrender the hand", G_CALLBACK (on_control_surrender_activate) },
-                { "hand-double-down", NULL, "_Double down", "D", "Double down", G_CALLBACK (on_control_double_activate) },
-                { "hand-split", NULL, "Split the hand", "P", "Split the hand", G_CALLBACK (on_control_split_activate) },
-                { "help-menu", NULL, "_Help" },
-                { "show-help-contents", GTK_STOCK_HELP, "_Contents", "F1", "Display help for this game", G_CALLBACK (on_help_contents_activate) },
-                { "show-about", GTK_STOCK_ABOUT, "_About", NULL, "About this game", G_CALLBACK (on_help_about_activate) },
+                { "game-menu", NULL, N_("_Game") },
+                { "new-game", GTK_STOCK_NEW, N_("_New game"), "<Control>N", N_("Start a new game"), G_CALLBACK (on_game_new_activate) },
+                { "restart-game", GTK_STOCK_REFRESH, N_("_Restart game"), "<Control>R", N_("Restart the current game"), G_CALLBACK (on_game_restart_activate) },
+                { "show-hint", GTK_STOCK_HELP, N_("_Hint"), NULL, N_("Get a hint for the next action"), G_CALLBACK (on_game_hint_activate) },
+                { "quit-game", GTK_STOCK_QUIT, NULL, "<Control>Q", N_("Quit application"), G_CALLBACK (on_game_quit_activate) },
+                { "settings-menu", NULL, N_("_Settings") },
+                { "show-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, N_("Show game preferences"), G_CALLBACK (on_preferences_activate) },
+                { "control-menu", NULL, N_("_Control") },
+                { "hand-deal", NULL, N_("Deal"), NULL, N_("Deal a new hand"), G_CALLBACK (on_control_deal_activate) },
+                { "hand-hit", NULL, N_("_Hit"), "H", N_("Add a card to the hand"), G_CALLBACK (on_control_hit_activate) },
+                { "hand-stand", NULL, N_("_Stand"), "S", N_("Stop adding cards to the hand"), G_CALLBACK (on_control_stand_activate) },
+                { "hand-surrender", NULL, N_("Surrender"), "R", N_("Surrender the hand"), G_CALLBACK (on_control_surrender_activate) },
+                { "hand-double-down", NULL, N_("_Double down"), "D", N_("Double down"), G_CALLBACK (on_control_double_activate) },
+                { "hand-split", NULL, N_("Split the hand"), "P", N_("Split the hand"), G_CALLBACK (on_control_split_activate) },
+                { "help-menu", NULL, N_("_Help")},
+                { "show-help-contents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Display help for this game"), G_CALLBACK (on_help_contents_activate) },
+                { "show-about", GTK_STOCK_ABOUT, NULL, NULL, N_("About this game"), G_CALLBACK (on_help_about_activate) },
         };
 
 	static GtkToggleActionEntry toggle_entries [] = {
-                { "show-toolbar", NULL, "_Toolbar", "<Control>T", "Show toolbar", G_CALLBACK (on_toolbar_activate), show_toolbar },
+                { "show-toolbar", NULL, N_("_Toolbar"), "<Control>T", N_("Show toolbar"), G_CALLBACK (on_toolbar_activate), show_toolbar },
         };
 
         toplevel_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -332,6 +332,7 @@ create_main_window (void)
         gtk_ui_manager_add_ui_from_string (ui, ui_definition, -1, &error);
 
         actions = gtk_action_group_new ("Actions");
+        gtk_action_group_set_translation_domain (actions, GETTEXT_PACKAGE);
         gtk_action_group_add_actions (actions, entries, G_N_ELEMENTS (entries), toplevel_window);
         gtk_action_group_add_toggle_actions (actions, toggle_entries, G_N_ELEMENTS (toggle_entries), toplevel_window);
         gtk_ui_manager_insert_action_group (ui, actions, 0);
@@ -686,7 +687,7 @@ main (int argc, char *argv [])
 
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
-        gtk_window_set_default_icon_name ("gnome-blackjack");
+        gtk_window_set_default_icon_from_file (PIXMAPDIR"/gnome-blackjack.png", NULL);
 
         bj_gconf_init (bj_gconf_client ());
 
