@@ -62,15 +62,6 @@ typedef struct {
   int sel;
 } DiceInfo;
 
-/* This is a little bigger than it needs to be */
-typedef struct _UndoInfo {
-  int player;
-  int field;
-  int fstate;
-  int oldscore;
-  struct _UndoInfo *prev;
-} UndoInfo;
-
 /* yahtzee.c */
 extern DiceInfo DiceValues[];
 extern Player players[];
@@ -83,14 +74,12 @@ extern int WinningScore;
 extern int DisplayComputerThoughts;
 extern int OnlyShowScores;
 extern int CurrentPlayer;
-extern int IsCheater;
 extern char *ProgramHeader;
 extern char *FieldLabels[NUM_FIELDS+EXTRA_FIELDS];
 extern char *DefaultPlayerNames[MAX_NUMBER_OF_PLAYERS];
 
 extern void YahtzeeInit(void);
 extern void NewGame(void);
-extern void YahtzeeDelay(void);
 extern int upper_total(int num);
 extern int lower_total(int num);
 extern int total_score(int num);
@@ -100,8 +89,6 @@ extern int find_straight(int run, int notstart, int notrun);
 extern int find_yahtzee(void);
 extern int add_dice(void);
 extern int play_score(int player, int field);
-extern int RegisterUndo(int player, int field, int fstate, int oldscore);
-extern int ExecSingleUndo(int screenupdate);
 extern void handle_play(int player);
 extern void play(void);
 extern void calc_random(void);
@@ -115,15 +102,14 @@ extern int FindWinner(void);
 int UndoPossible (void);
 
 /* Computer.c */
-extern void ComputerTurn(int player);
 extern void ComputerRolling(int player);
+extern void ComputerScoring(int player);
 
 /* Specific to a windowing system: gyahtzee.c/cyahtzee.c */
 extern void NewGame(void);
 extern void UpdateDie(int no);
 extern void ShowPlayer(int num, int field);
 extern void NextPlayer(void);
-extern void YahtzeeIdle(void);
 extern void ShowHighScores(void);
 
 enum { SCORE_OK=0, SLOT_USED, PLAYER_DONE, YAHTZEE_NEWGAME };
